[evolution-data-server] Update API documentation.



commit 8cd83e0994edc9f767a4bd5bef903c8624e6bddd
Author: Matthew Barnes <mbarnes redhat com>
Date:   Sun Dec 9 10:50:45 2012 -0500

    Update API documentation.

 addressbook/libebook/e-book-types.h                |    2 +
 .../libebook/e-source-backend-summary-setup.c      |    2 +
 .../libedata-book/e-book-backend-db-cache.c        |    2 +-
 addressbook/libedata-book/e-data-book-view.c       |    2 +
 .../addressbook/libebook/libebook-docs.sgml        |    1 +
 .../addressbook/libebook/libebook-sections.txt     |   30 ++++++++
 docs/reference/addressbook/libebook/libebook.types |    1 +
 .../libedata-book/libedata-book-sections.txt       |    5 ++
 docs/reference/camel/camel-sections.txt            |   10 ++-
 docs/reference/libebackend/libebackend-docs.xml    |    3 +
 .../reference/libebackend/libebackend-sections.txt |   65 +++++++++++++++++
 docs/reference/libebackend/libebackend.types       |    3 +
 .../libedataserver/libedataserver-sections.txt     |   14 ++++
 docs/reference/private/libedbus-private-docs.sgml  |    4 +
 .../private/libedbus-private-sections.txt          |   75 ++++++++++++++++++-
 docs/reference/private/libedbus-private.types      |    4 +
 libebackend/e-user-prompter-server.h               |    2 +-
 libebackend/e-user-prompter.c                      |    2 +-
 libebackend/e-user-prompter.h                      |   12 +++-
 libedataserver/e-data-server-util.c                |   41 ++++++-----
 libedataserver/e-data-server-util.h                |   45 +++++++-----
 21 files changed, 274 insertions(+), 51 deletions(-)
---
diff --git a/addressbook/libebook/e-book-types.h b/addressbook/libebook/e-book-types.h
index d778d91..d366f04 100644
--- a/addressbook/libebook/e-book-types.h
+++ b/addressbook/libebook/e-book-types.h
@@ -117,6 +117,8 @@ typedef struct {
  * @E_BOOK_INDEX_SUFFIX: An index suitable for searching contacts with a suffix pattern
  *
  * The type of index defined for e_source_backend_summary_setup_set_indexed_fields()
+ *
+ * Since: 3.8
  */
 typedef enum {
 	E_BOOK_INDEX_PREFIX = 0,
diff --git a/addressbook/libebook/e-source-backend-summary-setup.c b/addressbook/libebook/e-source-backend-summary-setup.c
index fe16811..2e7f595 100644
--- a/addressbook/libebook/e-source-backend-summary-setup.c
+++ b/addressbook/libebook/e-source-backend-summary-setup.c
@@ -439,6 +439,8 @@ e_source_backend_summary_setup_set_summary_fields (ESourceBackendSummarySetup *e
  * Fetches the #EContactFields configured to be indexed, with thier respective #EBookIndexTypes.
  *
  * Returns: (transfer full): The array of indexed #EContactFields.
+ *
+ * Since: 3.8
  */
 EContactField  *
 e_source_backend_summary_setup_get_indexed_fields (ESourceBackendSummarySetup  *extension,
diff --git a/addressbook/libedata-book/e-book-backend-db-cache.c b/addressbook/libedata-book/e-book-backend-db-cache.c
index e932d79..7bebb09 100644
--- a/addressbook/libedata-book/e-book-backend-db-cache.c
+++ b/addressbook/libedata-book/e-book-backend-db-cache.c
@@ -396,7 +396,7 @@ e_book_backend_db_cache_set_populated (DB *db)
 }
 
 /**
- * e_book_backend_cache_is_populated:
+ * e_book_backend_db_cache_is_populated:
  * @db: DB Handle
  *
  * Checks if @cache is populated.
diff --git a/addressbook/libedata-book/e-data-book-view.c b/addressbook/libedata-book/e-data-book-view.c
index 471349e..93fed8e 100644
--- a/addressbook/libedata-book/e-data-book-view.c
+++ b/addressbook/libedata-book/e-data-book-view.c
@@ -740,6 +740,8 @@ e_data_book_view_get_backend (EDataBookView *view)
  * Gets the s-expression used for matching contacts to @view.
  *
  * Returns: The #EBookBackendSExp used.
+ *
+ * Since: 3.8
  **/
 EBookBackendSExp *
 e_data_book_view_get_sexp (EDataBookView *view)
diff --git a/docs/reference/addressbook/libebook/libebook-docs.sgml b/docs/reference/addressbook/libebook/libebook-docs.sgml
index dedbcd5..0c2fc79 100644
--- a/docs/reference/addressbook/libebook/libebook-docs.sgml
+++ b/docs/reference/addressbook/libebook/libebook-docs.sgml
@@ -19,6 +19,7 @@
     <xi:include href="xml/e-destination.xml"/>
     <xi:include href="xml/e-address-western.xml"/>
     <xi:include href="xml/e-name-western.xml"/>
+    <xi:include href="xml/e-source-backend-summary-setup.xml"/>
   </chapter>
 
   <chapter>
diff --git a/docs/reference/addressbook/libebook/libebook-sections.txt b/docs/reference/addressbook/libebook/libebook-sections.txt
index 603e91b..cace685 100644
--- a/docs/reference/addressbook/libebook/libebook-sections.txt
+++ b/docs/reference/addressbook/libebook/libebook-sections.txt
@@ -236,6 +236,9 @@ e_contact_photo_free
 e_contact_geo_free
 e_contact_address_new
 e_contact_address_free
+e_contact_attr_list_copy
+e_contact_attr_list_free
+e_contact_field_type
 e_contact_field_name
 e_contact_pretty_name
 e_contact_field_id
@@ -257,12 +260,14 @@ E_TYPE_CONTACT_CERT
 E_TYPE_CONTACT_DATE
 E_TYPE_CONTACT_NAME
 E_TYPE_CONTACT_PHOTO
+E_TYPE_CONTACT_ATTR_LIST
 e_contact_get_type
 e_contact_address_get_type
 e_contact_cert_get_type
 e_contact_photo_get_type
 e_contact_name_get_type
 e_contact_date_get_type
+e_contact_attr_list_get_type
 EContactPhotoType
 <SUBSECTION Private>
 EContactPrivate
@@ -449,6 +454,7 @@ E_BOOK_ERROR_CORBA_EXCEPTION
 EBookViewStatus
 EBookChangeType
 EBookChange
+EBookIndexType
 </SECTION>
 
 <SECTION>
@@ -519,3 +525,27 @@ e_destination_get_type
 <SUBSECTION Private>
 EDestinationPrivate
 </SECTION>
+
+<SECTION>
+<FILE>e-source-backend-summary-setup</FILE>
+<TITLE>ESourceBackendSummarySetup</TITLE>
+E_SOURCE_EXTENSION_BACKEND_SUMMARY_SETUP
+ESourceBackendSummarySetup
+e_source_backend_summary_setup_get_summary_fields
+e_source_backend_summary_setup_set_summary_fieldsv
+e_source_backend_summary_setup_set_summary_fields
+e_source_backend_summary_setup_get_indexed_fields
+e_source_backend_summary_setup_set_indexed_fieldsv
+e_source_backend_summary_setup_set_indexed_fields
+<SUBSECTION Standard>
+E_SOURCE_BACKEND_SUMMARY_SETUP
+E_IS_SOURCE_BACKEND_SUMMARY_SETUP
+E_TYPE_SOURCE_BACKEND_SUMMARY_SETUP
+E_SOURCE_BACKEND_SUMMARY_SETUP_CLASS
+E_IS_SOURCE_BACKEND_SUMMARY_SETUP_CLASS
+E_SOURCE_BACKEND_SUMMARY_SETUP_GET_CLASS
+ESourceBackendSummarySetupClass
+<SUBSECTION Private>
+ESourceBackendSummarySetupPrivate
+e_source_backend_summary_setup_get_type
+</SECTION>
diff --git a/docs/reference/addressbook/libebook/libebook.types b/docs/reference/addressbook/libebook/libebook.types
index 8729e83..48f3478 100644
--- a/docs/reference/addressbook/libebook/libebook.types
+++ b/docs/reference/addressbook/libebook/libebook.types
@@ -6,4 +6,5 @@ e_book_client_view_get_type
 e_book_view_get_type
 e_contact_get_type
 e_destination_get_type
+e_source_backend_summary_setup_get_type
 e_vcard_get_type
diff --git a/docs/reference/addressbook/libedata-book/libedata-book-sections.txt b/docs/reference/addressbook/libedata-book/libedata-book-sections.txt
index 8f23cca..ece4460 100644
--- a/docs/reference/addressbook/libedata-book/libedata-book-sections.txt
+++ b/docs/reference/addressbook/libedata-book/libedata-book-sections.txt
@@ -157,6 +157,7 @@ e_book_backend_sexp_get_type
 EBookBackendSqliteDB
 EbSdbSearchData
 e_book_backend_sqlitedb_new
+e_book_backend_sqlitedb_new_full
 e_book_backend_sqlitedb_lock_updates
 e_book_backend_sqlitedb_unlock_updates
 e_book_backend_sqlitedb_add_contact
@@ -171,6 +172,8 @@ e_book_backend_sqlitedb_search_uids
 e_book_backend_sqlitedb_get_uids_and_rev
 e_book_backend_sqlitedb_get_is_populated
 e_book_backend_sqlitedb_set_is_populated
+e_book_backend_sqlitedb_get_revision
+e_book_backend_sqlitedb_set_revision
 e_book_backend_sqlitedb_get_sync_data
 e_book_backend_sqlitedb_set_sync_data
 e_book_backend_sqlitedb_get_key_value
@@ -183,6 +186,8 @@ e_book_backend_sqlitedb_get_partially_cached_ids
 e_book_backend_sqlitedb_delete_addressbook
 e_book_backend_sqlitedb_remove
 e_book_backend_sqlitedb_search_data_free
+e_book_backend_sqlitedb_check_summary_query
+e_book_backend_sqlitedb_check_summary_fields
 e_book_backend_sqlitedb_is_summary_query
 e_book_backend_sqlitedb_is_summary_fields
 <SUBSECTION Standard>
diff --git a/docs/reference/camel/camel-sections.txt b/docs/reference/camel/camel-sections.txt
index bdd9a73..73332b3 100644
--- a/docs/reference/camel/camel-sections.txt
+++ b/docs/reference/camel/camel-sections.txt
@@ -794,6 +794,8 @@ camel_imapx_conn_manager_get_type
 <TITLE>CamelIMAPXFolder</TITLE>
 CamelIMAPXFolder
 camel_imapx_folder_new
+camel_imapx_folder_dup_quota_root_names
+camel_imapx_folder_set_quota_root_names
 <SUBSECTION Standard>
 CAMEL_IMAPX_FOLDER
 CAMEL_IS_IMAPX_FOLDER
@@ -803,7 +805,7 @@ CAMEL_IS_IMAPX_FOLDER_CLASS
 CAMEL_IMAPX_FOLDER_GET_CLASS
 CamelIMAPXFolderClass
 <SUBSECTION Private>
-CamelIMAPXFolder
+CamelIMAPXFolderPrivate
 camel_imapx_folder_get_type
 imapx_get_filename
 </SECTION>
@@ -852,8 +854,8 @@ camel_imapx_server_manage_subscription
 camel_imapx_server_create_folder
 camel_imapx_server_delete_folder
 camel_imapx_server_rename_folder
+camel_imapx_server_update_quota_info
 camel_imapx_server_get_job_queue_info
-CamelIMAPXUntaggedRespHandler
 CamelIMAPXUntaggedRespHandlerDesc
 camel_imapx_server_register_untagged_handler
 camel_imapx_server_command_run
@@ -931,6 +933,8 @@ camel_imapx_settings_get_type
 CamelIMAPXStore
 camel_imapx_store_get_server
 camel_imapx_store_op_done
+camel_imapx_store_dup_quota_info
+camel_imapx_store_set_quota_info
 <SUBSECTION Standard>
 CAMEL_IMAPX_STORE
 CAMEL_IS_IMAPX_STORE
@@ -1704,7 +1708,7 @@ camel_msgport_fd
 camel_msgport_push
 camel_msgport_pop
 camel_msgport_try_pop
-camel_msgport_timed_pop
+camel_msgport_timeout_pop
 camel_msgport_reply
 camel_msgport_prfd
 </SECTION>
diff --git a/docs/reference/libebackend/libebackend-docs.xml b/docs/reference/libebackend/libebackend-docs.xml
index 05b6d72..f63f1ba 100644
--- a/docs/reference/libebackend/libebackend-docs.xml
+++ b/docs/reference/libebackend/libebackend-docs.xml
@@ -34,6 +34,9 @@
     <xi:include href="xml/e-file-cache.xml"/>
     <xi:include href="xml/e-db3-utils.xml"/>
     <xi:include href="xml/e-sqlite3-vfs.xml"/>
+    <xi:include href="xml/e-user-prompter.xml"/>
+    <xi:include href="xml/e-user-prompter-server.xml"/>
+    <xi:include href="xml/e-user-prompter-server-extension.xml"/>
   </chapter>
 
   <chapter>
diff --git a/docs/reference/libebackend/libebackend-sections.txt b/docs/reference/libebackend/libebackend-sections.txt
index 8337e13..f941b11 100644
--- a/docs/reference/libebackend/libebackend-sections.txt
+++ b/docs/reference/libebackend/libebackend-sections.txt
@@ -406,3 +406,68 @@ e_source_permission_flags_get_type
 <FILE>e-sqlite3-vfs</FILE>
 e_sqlite3_vfs_init
 </SECTION>
+
+<SECTION>
+<FILE>e-user-prompter</FILE>
+<TITLE>EUserPrompter</TITLE>
+EUserPrompter
+e_user_prompter_new
+e_user_prompter_prompt
+e_user_prompter_prompt_finish
+e_user_prompter_prompt_sync
+e_user_prompter_extension_prompt
+e_user_prompter_extension_prompt_finish
+e_user_prompter_extension_prompt_sync
+<SUBSECTION Standard>
+E_USER_PROMPTER
+E_IS_USER_PROMPTER
+E_TYPE_USER_PROMPTER
+E_USER_PROMPTER_CLASS
+E_IS_USER_PROMPTER_CLASS
+E_USER_PROMPTER_GET_CLASS
+EUserPrompterClass
+<SUBECTION Private>
+EUserPrompterPrivate
+e_user_prompter_get_type
+</SECTION>
+
+<SECTION>
+<FILE>e-user-prompter-server</FILE>
+<TITLE>EUserPrompterServer</TITLE>
+E_USER_PROMPTER_SERVER_OBJECT_PATH
+EUserPrompterServer
+e_user_prompter_server_new
+e_user_prompter_server_response
+e_user_prompter_server_register
+<SUBSECTION Standard>
+E_USER_PROMPTER_SERVER
+E_IS_USER_PROMPTER_SERVER
+E_TYPE_USER_PROMPTER_SERVER
+E_USER_PROMPTER_SERVER_CLASS
+E_IS_USER_PROMPTER_SERVER_CLASS
+E_USER_PROMPTER_SERVER_GET_CLASS
+EUserPrompterServerClass
+<SUBSECTION Private>
+EUserPrompterServerPrivate
+e_user_prompter_server_get_type
+</SECTION>
+
+<SECTION>
+<FILE>e-user-prompter-server-extension</FILE>
+<TITLE>EUserPrompterServerExtension</TITLE>
+EUserPrompterServerExtension
+e_user_prompter_server_extension_prompt
+e_user_prompter_server_extension_response
+<SUBSECTION Standard>
+E_USER_PROMPTER_SERVER_EXTENSION
+E_IS_USER_PROMPTER_SERVER_EXTENSION
+E_TYPE_USER_PROMPTER_SERVER_EXTENSION
+E_USER_PROMPTER_SERVER_EXTENSION_CLASS
+E_IS_USER_PROMPTER_SERVER_EXTENSION_CLASS
+E_USER_PROMPTER_SERVER_EXTENSION_GET_CLASS
+EUserPrompterServerExtensionClass
+<SUBSECTION Private>
+EUserPrompterServerExtensionPrivate
+e_user_prompter_server_extension_get_type
+</SECTION>
+
diff --git a/docs/reference/libebackend/libebackend.types b/docs/reference/libebackend/libebackend.types
index 1a5d962..43414ef 100644
--- a/docs/reference/libebackend/libebackend.types
+++ b/docs/reference/libebackend/libebackend.types
@@ -15,3 +15,6 @@ e_module_get_type
 e_offline_listener_get_type
 e_server_side_source_get_type
 e_source_registry_server_get_type
+e_user_prompter_get_type
+e_user_prompter_server_get_type
+e_user_prompter_server_extension_get_type
diff --git a/docs/reference/libedataserver/libedataserver-sections.txt b/docs/reference/libedataserver/libedataserver-sections.txt
index dc2e1e4..526778d 100644
--- a/docs/reference/libedataserver/libedataserver-sections.txt
+++ b/docs/reference/libedataserver/libedataserver-sections.txt
@@ -658,6 +658,8 @@ e_source_mail_submission_set_sent_folder
 e_source_mail_submission_get_transport_uid
 e_source_mail_submission_dup_transport_uid
 e_source_mail_submission_set_transport_uid
+e_source_mail_submission_get_replies_to_origin_folder
+e_source_mail_submission_set_replies_to_origin_folder
 <SUBSECTION Standard>
 E_SOURCE_MAIL_SUBMISSION
 E_IS_SOURCE_MAIL_SUBMISSION
@@ -1130,6 +1132,7 @@ e_util_utf8_strcasecmp
 e_util_utf8_remove_accents
 e_util_utf8_make_valid
 e_util_utf8_data_make_valid
+e_util_utf8_normalize
 e_util_ensure_gdbus_string
 e_util_gthread_id
 e_filename_make_safe
@@ -1149,6 +1152,8 @@ e_file_recursive_delete
 e_file_recursive_delete_finish
 e_binding_transform_enum_value_to_nick
 e_binding_transform_enum_nick_to_value
+e_enum_from_string
+e_enum_to_string
 EAsyncClosure
 e_async_closure_new
 e_async_closure_wait
@@ -1160,6 +1165,15 @@ e_util_get_localedir
 e_util_replace_prefix
 e_data_server_util_get_dbus_call_timeout
 e_data_server_util_set_dbus_call_timeout
+ENamedParameters
+e_named_parameters_new
+e_named_parameters_new_strv
+e_named_parameters_free
+e_named_parameters_clear
+e_named_parameters_assign
+e_named_parameters_set
+e_named_parameters_get
+e_named_parameters_test
 </SECTION>
 
 <SECTION>
diff --git a/docs/reference/private/libedbus-private-docs.sgml b/docs/reference/private/libedbus-private-docs.sgml
index 5278f95..6518000 100644
--- a/docs/reference/private/libedbus-private-docs.sgml
+++ b/docs/reference/private/libedbus-private-docs.sgml
@@ -35,6 +35,9 @@
     <xi:include href="xml/e-dbus-authenticator.xml"/>
     <xi:include href="xml/e-dbus-authenticator-proxy.xml"/>
     <xi:include href="xml/e-dbus-authenticator-skeleton.xml"/>
+    <xi:include href="xml/e-dbus-user-prompter.xml"/>
+    <xi:include href="xml/e-dbus-user-prompter-proxy.xml"/>
+    <xi:include href="xml/e-dbus-user-prompter-skeleton.xml"/>
   </chapter>
 
   <chapter>
@@ -46,6 +49,7 @@
     <xi:include href="../../../private/e-dbus-source-org.gnome.evolution.dataserver.Source.RemoteDeletable.xml"/>
     <xi:include href="../../../private/e-dbus-source-manager-org.gnome.evolution.dataserver.SourceManager.xml"/>
     <xi:include href="../../../private/e-dbus-authenticator-org.gnome.evolution.dataserver.Authenticator.xml"/>
+    <xi:include href="../../../private/e-dbus-user-prompter-org.gnome.evolution.dataserver.UserPrompter.xml"/>
   </chapter>
 
   <index id="api-index-full">
diff --git a/docs/reference/private/libedbus-private-sections.txt b/docs/reference/private/libedbus-private-sections.txt
index 486bf25..1ebfc62 100644
--- a/docs/reference/private/libedbus-private-sections.txt
+++ b/docs/reference/private/libedbus-private-sections.txt
@@ -456,12 +456,12 @@ e_dbus_source_removable_get_type
 <FILE>e-dbus-source-removable-proxy</FILE>
 <TITLE>EDBusSourceRemovableProxy</TITLE>
 EDBusSourceRemovableProxy
+e_dbus_source_removable_proxy_new_sync
 e_dbus_source_removable_proxy_new
 e_dbus_source_removable_proxy_new_finish
+e_dbus_source_removable_proxy_new_for_bus_sync
 e_dbus_source_removable_proxy_new_for_bus
 e_dbus_source_removable_proxy_new_for_bus_finish
-e_dbus_source_removable_proxy_new_for_bus_sync
-e_dbus_source_removable_proxy_new_sync
 <SUBSECTION Standard>
 E_DBUS_SOURCE_REMOVABLE_PROXY
 E_DBUS_IS_SOURCE_REMOVABLE_PROXY
@@ -517,12 +517,12 @@ e_dbus_source_writable_get_type
 <FILE>e-dbus-source-writable-proxy</FILE>
 <TITLE>EDBusSourceWritableProxy</TITLE>
 EDBusSourceWritableProxy
+e_dbus_source_writable_proxy_new_sync
 e_dbus_source_writable_proxy_new
 e_dbus_source_writable_proxy_new_finish
+e_dbus_source_writable_proxy_new_for_bus_sync
 e_dbus_source_writable_proxy_new_for_bus
 e_dbus_source_writable_proxy_new_for_bus_finish
-e_dbus_source_writable_proxy_new_for_bus_sync
-e_dbus_source_writable_proxy_new_sync
 <SUBSECTION Standard>
 E_DBUS_SOURCE_WRITABLE_PROXY
 E_DBUS_IS_SOURCE_WRITABLE_PROXY
@@ -554,3 +554,70 @@ EDBusSourceWritableSkeletonPrivate
 e_dbus_source_writable_skeleton_get_type
 </SECTION>
 
+<SECTION>
+<FILE>e-dbus-user-prompter</FILE>
+<TITLE>EDBusUserPrompter</TITLE>
+EDBusUserPrompter
+e_dbus_user_prompter_call_extension_prompt_sync
+e_dbus_user_prompter_call_extension_prompt
+e_dbus_user_prompter_call_extension_prompt_finish
+e_dbus_user_prompter_complete_extension_prompt
+e_dbus_user_prompter_call_prompt_sync
+e_dbus_user_prompter_call_prompt
+e_dbus_user_prompter_call_prompt_finish
+e_dbus_user_prompter_complete_prompt
+e_dbus_user_prompter_emit_extension_response
+e_dbus_user_prompter_emit_response
+e_dbus_user_prompter_interface_info
+e_dbus_user_prompter_override_properties
+<SUBSECTION Standard>
+E_DBUS_USER_PROMPTER
+E_DBUS_IS_USER_PROMPTER
+E_DBUS_TYPE_USER_PROMPTER
+E_DBUS_USER_PROMPTER_GET_IFACE
+EDBusUserPrompterIface
+<SUBSECTION Private>
+e_dbus_user_prompter_get_type
+</SECTION>
+
+<SECTION>
+<FILE>e-dbus-user-prompter-proxy</FILE>
+<TITLE>EDBusUserPrompterProxy</TITLE>
+EDBusUserPrompterProxy
+e_dbus_user_prompter_proxy_new_sync
+e_dbus_user_prompter_proxy_new
+e_dbus_user_prompter_proxy_new_finish
+e_dbus_user_prompter_proxy_new_for_bus_sync
+e_dbus_user_prompter_proxy_new_for_bus
+e_dbus_user_prompter_proxy_new_for_bus_finish
+<SUBSECTION Standard>
+E_DBUS_USER_PROMPTER_PROXY
+E_DBUS_IS_USER_PROMPTER_PROXY
+E_DBUS_TYPE_USER_PROMPTER_PROXY
+E_DBUS_USER_PROMPTER_PROXY_CLASS
+E_DBUS_IS_USER_PROMPTER_PROXY_CLASS
+E_DBUS_USER_PROMPTER_PROXY_GET_CLASS
+EDBusUserPrompterProxyClass
+<SUBSECTION Private>
+EDBusUserPrompterProxyPrivate
+e_dbus_user_prompter_proxy_get_type
+</SECTION>
+
+<SECTION>
+<FILE>e-dbus-user-prompter-skeleton</FILE>
+<TITLE>EDBusUserPrompterSkeleton</TITLE>
+EDBusUserPrompterSkeleton
+e_dbus_user_prompter_skeleton_new
+<SUBSECTION Standard>
+E_DBUS_USER_PROMPTER_SKELETON
+E_DBUS_IS_USER_PROMPTER_SKELETON
+E_DBUS_TYPE_USER_PROMPTER_SKELETON
+E_DBUS_USER_PROMPTER_SKELETON_CLASS
+E_DBUS_IS_USER_PROMPTER_SKELETON_CLASS
+E_DBUS_USER_PROMPTER_SKELETON_GET_CLASS
+EDBusUserPrompterSkeletonClass
+<SUBSECTION Private>
+EDBusUserPrompterSkeletonPrivate
+e_dbus_user_prompter_skeleton_get_type
+</SECTION>
+
diff --git a/docs/reference/private/libedbus-private.types b/docs/reference/private/libedbus-private.types
index bd0c788..3896388 100644
--- a/docs/reference/private/libedbus-private.types
+++ b/docs/reference/private/libedbus-private.types
@@ -1,6 +1,7 @@
 #include <private/e-dbus-source.h>
 #include <private/e-dbus-source-manager.h>
 #include <private/e-dbus-authenticator.h>
+#include <private/e-dbus-user-prompter.h>
 
 e_dbus_object_get_type
 e_dbus_object_proxy_get_type
@@ -27,3 +28,6 @@ e_dbus_source_remote_deletable_skeleton_get_type
 e_dbus_authenticator_get_type
 e_dbus_authenticator_proxy_get_type
 e_dbus_authenticator_skeleton_get_type
+e_dbus_user_prompter_get_type
+e_dbus_user_prompter_proxy_get_type
+e_dbus_user_prompter_skeleton_get_type
diff --git a/libebackend/e-user-prompter-server.h b/libebackend/e-user-prompter-server.h
index e1cca20..a48c28b 100644
--- a/libebackend/e-user-prompter-server.h
+++ b/libebackend/e-user-prompter-server.h
@@ -88,7 +88,7 @@ GType		e_user_prompter_server_get_type	(void);
 EDBusServer *	e_user_prompter_server_new	(void);
 void		e_user_prompter_server_response	(EUserPrompterServer *server,
 						 gint prompt_id,
-						 gint button_index,
+						 gint response,
 						 const ENamedParameters *extension_values);
 
 gboolean	e_user_prompter_server_register	(EUserPrompterServer *server,
diff --git a/libebackend/e-user-prompter.c b/libebackend/e-user-prompter.c
index fea0e74..3e8e9b7 100644
--- a/libebackend/e-user-prompter.c
+++ b/libebackend/e-user-prompter.c
@@ -577,7 +577,7 @@ e_user_prompter_extension_prompt_finish (EUserPrompter *prompter,
 }
 
 /**
- * e_user_prompter_extension_prompt:
+ * e_user_prompter_extension_prompt_sync:
  * @prompter: an #EUserPrompter
  * @dialog_name: name of a dialog to invoke
  * @in_parameters: (allow-none): optional parameters to pass to extension; can be %NULL
diff --git a/libebackend/e-user-prompter.h b/libebackend/e-user-prompter.h
index c595f79..8273b55 100644
--- a/libebackend/e-user-prompter.h
+++ b/libebackend/e-user-prompter.h
@@ -33,12 +33,18 @@
 #define E_USER_PROMPTER(obj) \
 	(G_TYPE_CHECK_INSTANCE_CAST \
 	((obj), E_TYPE_USER_PROMPTER, EUserPrompter))
+#define E_USER_PROMPTER_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_CAST \
+	((cls), E_TYPE_USER_PROMPTER, EUserPrompterClass))
 #define E_IS_USER_PROMPTER(obj) \
 	(G_TYPE_CHECK_INSTANCE_TYPE \
 	((obj), E_TYPE_USER_PROMPTER))
-#define E_USER_PROMPTER_GET_INTERFACE(obj) \
-	(G_TYPE_INSTANCE_GET_INTERFACE \
-	((obj), E_TYPE_USER_PROMPTER, EUserPrompterInterface))
+#define E_IS_USER_PROMPTER_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_TYPE \
+	((cls), E_TYPE_USER_PROMPTER))
+#define E_USER_PROMPTER_GET_CLASS(obj) \
+	(G_TYPE_INSTANCE_GET_CLASS \
+	((obj), E_TYPE_USER_PROMPTER, EUserPrompterClass))
 
 G_BEGIN_DECLS
 
diff --git a/libedataserver/e-data-server-util.h b/libedataserver/e-data-server-util.h
index 5fdca11..455bece 100644
--- a/libedataserver/e-data-server-util.h
+++ b/libedataserver/e-data-server-util.h
@@ -105,11 +105,12 @@ gboolean	e_binding_transform_enum_nick_to_value
 						 const GValue *source_value,
 						 GValue *target_value,
 						 gpointer not_used);
-gboolean        e_enum_from_string              (GType type,
+
+gboolean	e_enum_from_string		(GType enum_type,
 						 const gchar *string,
 						 gint *enum_value);
-const gchar    *e_enum_to_string                (GType etype,
-						 gint eval);
+const gchar *	e_enum_to_string		(GType enum_type,
+						 gint enum_value);
 
 typedef struct _EAsyncClosure EAsyncClosure;
 
@@ -135,23 +136,31 @@ void		e_data_server_util_set_dbus_call_timeout
 						(gint timeout_msec);
 
 /* utility functions for easier processing of named parameters */
+
+/**
+ * ENamedParameters:
+ *
+ * Since: 3.8
+ **/
 typedef GPtrArray ENamedParameters;
 
-ENamedParameters *	e_named_parameters_new		(void);
-ENamedParameters *	e_named_parameters_new_strv	(const gchar * const *strv);
-void			e_named_parameters_free		(ENamedParameters *parameters);
-void			e_named_parameters_clear	(ENamedParameters *parameters);
-void			e_named_parameters_assign	(ENamedParameters *parameters,
-							 const ENamedParameters *from);
-void			e_named_parameters_set		(ENamedParameters *parameters,
-							 const gchar *name,
-							 const gchar *value);
-const gchar *		e_named_parameters_get		(const ENamedParameters *parameters,
-							 const gchar *name);
-gboolean		e_named_parameters_test		(const ENamedParameters *parameters,
-							 const gchar *name,
-							 const gchar *value,
-							 gboolean case_sensitively);
+ENamedParameters *
+		e_named_parameters_new		(void);
+ENamedParameters *
+		e_named_parameters_new_strv	(const gchar * const *strv);
+void		e_named_parameters_free		(ENamedParameters *parameters);
+void		e_named_parameters_clear	(ENamedParameters *parameters);
+void		e_named_parameters_assign	(ENamedParameters *parameters,
+						 const ENamedParameters *from);
+void		e_named_parameters_set		(ENamedParameters *parameters,
+						 const gchar *name,
+						 const gchar *value);
+const gchar *	e_named_parameters_get		(const ENamedParameters *parameters,
+						 const gchar *name);
+gboolean	e_named_parameters_test		(const ENamedParameters *parameters,
+						 const gchar *name,
+						 const gchar *value,
+						 gboolean case_sensitively);
 
 G_END_DECLS
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libedataserver/e-data-server-util.c b/libedataserver/e-data-server-util.c
index cce8cad..accccfe 100644
--- a/libedataserver/e-data-server-util.c
+++ b/libedataserver/e-data-server-util.c
@@ -1327,7 +1327,7 @@ e_binding_transform_enum_nick_to_value (GBinding *binding,
 
 /**
  * e_enum_from_string:
  * @type: The enum type
  * @string: The string containing the enum value or nick
  * @enum_value: A return location to store the result
  *
@@ -1340,17 +1340,17 @@ e_binding_transform_enum_nick_to_value (GBinding *binding,
  * Since: 3.8
  */
 gboolean
-e_enum_from_string (GType type,
+e_enum_from_string (GType enum_type,
 		    const gchar *string,
 		    gint *enum_value)
 {
-	GEnumClass *eclass;
+	GEnumClass *enum_class;
 	GEnumValue *ev;
 	gchar *endptr;
 	gint value;
 	gboolean retval = TRUE;
 
-	g_return_val_if_fail (G_TYPE_IS_ENUM (type), FALSE);
+	g_return_val_if_fail (G_TYPE_IS_ENUM (enum_type), FALSE);
 	g_return_val_if_fail (string != NULL, FALSE);
 
 	value = g_ascii_strtoull (string, &endptr, 0);
@@ -1358,17 +1358,17 @@ e_enum_from_string (GType type,
 		/* parsed a number */
 		*enum_value = value;
 	else {
-		eclass = g_type_class_ref (type);
-		ev = g_enum_get_value_by_name (eclass, string);
+		enum_class = g_type_class_ref (enum_type);
+		ev = g_enum_get_value_by_name (enum_class, string);
 		if (!ev)
-			ev = g_enum_get_value_by_nick (eclass, string);
+			ev = g_enum_get_value_by_nick (enum_class, string);
 
 		if (ev)
 			*enum_value = ev->value;
 		else
 			retval = FALSE;
 
-		g_type_class_unref (eclass);
+		g_type_class_unref (enum_class);
 	}
 
 	return retval;
@@ -1376,8 +1376,8 @@ e_enum_from_string (GType type,
 
 /**
  * e_enum_to_string:
  * @etype: An enum type
  * @eval: The enum value to convert
  *
  * Converts an enum value to a string using strings from the GType system.
  *
@@ -1386,25 +1386,26 @@ e_enum_from_string (GType type,
  * Since: 3.8
  */
 const gchar *
-e_enum_to_string (GType etype,
-		  gint  eval)
+e_enum_to_string (GType enum_type,
+		  gint enum_value)
 {
-	GEnumClass  *eclass;
+	GEnumClass *enum_class;
 	const gchar *string = NULL;
-	guint       i;
+	guint i;
   
-	eclass = g_type_class_ref (etype);
+	enum_class = g_type_class_ref (enum_type);
 
-	g_return_val_if_fail (eclass != NULL, NULL);
+	g_return_val_if_fail (enum_class != NULL, NULL);
 
-	for (i = 0; i < eclass->n_values; i++) {
-		if (eval == eclass->values[i].value) {
-			string = eclass->values[i].value_nick;
+	for (i = 0; i < enum_class->n_values; i++) {
+		if (enum_value == enum_class->values[i].value) {
+			string = enum_class->values[i].value_nick;
 			break;
 		}
 	}
 
-	g_type_class_unref (eclass);
+	g_type_class_unref (enum_class);
+
 	return string;
 }
 
@@ -1327,7 +1327,7 @@ e_binding_transform_enum_nick_to_value (GBinding *binding,
 /**
  * e_enum_from_string:
- * @type: The enum type
+ * @enum_type: The enum type
  * @string: The string containing the enum value or nick
  * @enum_value: A return location to store the result
@@ -1376,8 +1376,8 @@ e_enum_from_string (GType type,
 /**
  * e_enum_to_string:
- * @etype: An enum type
- * @eval: The enum value to convert
+ * @enum_type: An enum type
+ * @enum_value: The enum value to convert
  *
  * Converts an enum value to a string using strings from the GType system.